Ext.namespace('dSA', 'dSA.actions', 'dSA.util', 'dSA.dialogs',
              'dSA.actions.singlepresence', 'dSS', 'dSS.config');

dSA.actions.singlepresence.Window = Ext.extend(Ext.Window,
{
    constructor: function(config)
    {
        if (config.width === undefined)
        {
            config.width = 480;
        }

        this.timeout = config.timeout;
        if (this.timeout === undefined) {
            this.timeout = 12;
        }

        this.maskElement = config.maskElement;

        this.dsuid = config.dsuid;
        this.dsmdsuid = config.dsmdsuid;
        this.name = config.name;
        this.wasPresent = config.dsuidpresent;

        this.closeButton =
        {
            xtype: 'button',
            text: dSA._("Close"),
            scope: this,
            handler: function()
            {
                this.closed = true;
                this.close();

                if (this.maskElement !== undefined)
                {
                    this.maskElement.unmask();
                }
            }
        };

        var infopanel = dSA.dialogs.CreateDefaultDeviceInfoPanel(config.name,
                                                               config.displayid,
                                                                 true);
        Ext.apply(this,
        {
            title: dSA._("Update Device Status"),
            bodyBorder: false,
            padding: 5,
            resizable: false,
            items:
            [
                {
                    xtype: 'panel',
                    ref: 'mainpanel',
                    padding: 5,
                    border: false,
                    bodyBorder: false,
                    frame: false,
                    bodyCfg:
                    {
                        cls: 'x-window-body'
                    },
                    items:
                    [
                        infopanel,
                        {
                            xtype: 'panel',
                            padding: 5,
                            ref: 'datapanel',
                            cls: 'x-text-align-left x-text-nowrap',
                            html: dSA._("Device status") + ':&nbsp;...'
                        }
                    ]
                }
            ],
            buttonAlign: 'right',
            iconCls: 'loading-indicator-small',
            buttons:
            [
                this.closeButton
            ]
        });

        dSA.actions.singlepresence.Window.superclass.constructor.apply(this, arguments);

        this.on('afterrender',
            function()
            {
                if (this.maskElement !== undefined)
                {
                    this.maskElement.mask();
                }

                this.tID = dSA.functions.CheckSingleDevicePresence(this.dsuid,
                        this.dsmdsuid,
                        this.timeout,
                        this.devicePresenceCallback.createDelegate(this));
            },
            this);

        this.on('beforedestroy',
            function()
            {
                if (this.tID !== undefined)
                {
                    Ext.Ajax.abort(this.tID);
                }

                if (this.maskElement !== undefined)
                {
                    this.maskElement.unmask();
                }
            },
            this);
    },
    devicePresenceCallback: function(success, isPresent)
    {
        this.tID = undefined;

        if (this.closed === true)
        {
            return;
        }

        if (success !== true)
        {
            this.close();
            return;
        }

        this.setIconClass('dSA_DevicePresenceTitle');

        this.mainpanel.datapanel.update(dSA._("Device status") + ':&nbsp;' +
                            (isPresent ? dSA._("Active") : dSA._("Inactive")));

        if (isPresent != this.wasPresent)
        {
            if (dSS.module === true) {
                dSS.MessageBus.fireEvent('reloadapartment');
                dSS.config.firstLoad = false;
            }
        }
    }
});

dSA.actions.singlepresence.Test = function(displayid, dsid, dsuid,
                                           dsmdsuid, name,
                                           present, maskEl)
{
    var p = new dSA.actions.singlepresence.Window(
    {
        width: 400,
        name: name,
        displayid: displayid,
        dsid: dsid,
        dsuid: dsuid,
        dsmdsuid: dsmdsuid,
        dsuidpresent: present,
        maskElement: maskEl
    });
    p.show();
};
